pub struct StackWindow<'a, I>where
I: IntCO,{ /* private fields */ }Implementations
Sourceimpl<'a, I> StackWindow<'a, I>where
I: IntCO,
impl<'a, I> StackWindow<'a, I>where
I: IntCO,
Sourceimpl<I> StackWindow<'_, I>where
I: IntCO,
impl<I> StackWindow<'_, I>where
I: IntCO,
Sourcepub fn iter_height_runs(
&self,
) -> impl DoubleEndedIterator<Item = HeightRun<I>> + ExactSizeIterator
pub fn iter_height_runs( &self, ) -> impl DoubleEndedIterator<Item = HeightRun<I>> + ExactSizeIterator
Iterates over constant-height runs inside this window.
Unlike IntCOStack::iter_height_segments, this includes zero-height
runs because window-level mappings may assign a non-zero value to
height zero.
Sourceimpl<I> StackWindow<'_, I>
impl<I> StackWindow<'_, I>
Sourcepub fn par_iter_height_runs(
&self,
) -> impl IndexedParallelIterator<Item = HeightRun<I>>
pub fn par_iter_height_runs( &self, ) -> impl IndexedParallelIterator<Item = HeightRun<I>>
Iterates in parallel over constant-height runs inside this window.
The run range is represented as an indexed integer range, so Rayon can split the work directly. This is mainly useful when the per-run mapping is expensive or the window contains many height changes.